from setuptools import setup, find_packages

classifiers = [
    'Development Status :: 5 - Production/Stable',
    'Intended Audience :: Education',
    'Operating System :: Microsoft :: Windows :: Windows 10',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3'
]

setup(
    name='pyrandmeme',
    version='0.0.4',
    description='Random memes for discord.py',
    Long_description=open('README.md').read() + '\n\n' + open('CHANGELOG.txt').read(),
    url='',
    author='Poggy',
    author_email='poggywastaken123@gmail.com',
    License='MIT',
    classifiers=classifiers,
    keywords='memes',
    packages=find_packages(),
    install_requires=[
        'aiohttp',
        'discord',
        'random2'
    ]
)


import aiohttp
import discord
import random2


async def pyrandmeme():
    pymeme = discord.Embed(title="Test", description="Test", color=0xe91e63)
    async with aiohttp.ClientSession() as cs:
        async with cs.get('https://www.reddit.com/r/memes/new.json?sort=hot') as r:
            res = await r.json()
            pymeme.set_image(url=res['data']['children'][random2.randint(0, 25)]['data']['url'])
            return pymeme
        await pyrandmeme()